@@ -46,7 +46,7 @@
 #   include <sys/ioctl.h>
 #endif
 
-#if defined(__linux) || defined(__APPLE__) || defined(__FreeBSD__)
+#if defined(__linux__) || defined(__APPLE__) || defined(__FreeBSD__)
 #  include <ifaddrs.h>
 #elif defined(__sun)
 #  include <sys/sockio.h>
@@ -346,7 +346,7 @@ getLocalAddresses(ProtocolSupport protocol, bool includeLoopback, bool singleAdd
 
         free(adapter_addresses);
     }
-#elif defined(__linux) || defined(__APPLE__) || defined(__FreeBSD__)
+#elif defined(__linux__) || defined(__APPLE__) || defined(__FreeBSD__)
     struct ifaddrs* ifap;
     if(::getifaddrs(&ifap) == SOCKET_ERROR)
     {
@@ -448,40 +448,40 @@ getLocalAddresses(ProtocolSupport protocol, bool includeLoopback, bool singleAdd
         numaddrs = ifc.ifc_len / static_cast<int>(sizeof(struct ifreq));
         struct ifreq* ifr = ifc.ifc_req;
         set<string> interfaces;
-        for(int i = 0; i < numaddrs; ++i)
+        for(int j = 0; j < numaddrs; ++j)
         {
-            if(!(ifr[i].ifr_flags & IFF_LOOPBACK)) // Don't include loopback interface addresses
+            if(!(ifr[j].ifr_flags & IFF_LOOPBACK)) // Don't include loopback interface addresses
             {
                 //
                 // On Solaris the above Loopback check does not always work so we double
                 // check the address below. Solaris also returns duplicate entries that need
                 // to be filtered out.
                 //
-                if(ifr[i].ifr_addr.sa_family == AF_INET && protocol != EnableIPv6)
+                if(ifr[j].ifr_addr.sa_family == AF_INET && protocol != EnableIPv6)
                 {
                     Address addr;
-                    memcpy(&addr.saStorage, &ifr[i].ifr_addr, sizeof(sockaddr_in));
+                    memcpy(&addr.saStorage, &ifr[j].ifr_addr, sizeof(sockaddr_in));
                     if(addr.saIn.sin_addr.s_addr != 0 &&
                        (includeLoopback || addr.saIn.sin_addr.s_addr != htonl(INADDR_LOOPBACK)))
                     {
-                        if(!singleAddressPerInterface || interfaces.find(ifr[i].ifr_name) == interfaces.end())
+                        if(!singleAddressPerInterface || interfaces.find(ifr[j].ifr_name) == interfaces.end())
                         {
                             result.push_back(addr);
-                            interfaces.insert(ifr[i].ifr_name);
+                            interfaces.insert(ifr[j].ifr_name);
                         }
                     }
                 }
-                else if(ifr[i].ifr_addr.sa_family == AF_INET6 && protocol != EnableIPv4)
+                else if(ifr[j].ifr_addr.sa_family == AF_INET6 && protocol != EnableIPv4)
                 {
                     Address addr;
-                    memcpy(&addr.saStorage, &ifr[i].ifr_addr, sizeof(sockaddr_in6));
+                    memcpy(&addr.saStorage, &ifr[j].ifr_addr, sizeof(sockaddr_in6));
                     if(!IN6_IS_ADDR_UNSPECIFIED(&addr.saIn6.sin6_addr) &&
                        (includeLoopback || !IN6_IS_ADDR_LOOPBACK(&addr.saIn6.sin6_addr)))
                     {
-                        if(!singleAddressPerInterface || interfaces.find(ifr[i].ifr_name) == interfaces.end())
+                        if(!singleAddressPerInterface || interfaces.find(ifr[j].ifr_name) == interfaces.end())
                         {
                             result.push_back(addr);
-                            interfaces.insert(ifr[i].ifr_name);
+                            interfaces.insert(ifr[j].ifr_name);
                         }
                     }
                 }
@@ -648,7 +648,7 @@ getInterfaceIndex(const string& intf)
     //
     if(isAddr)
     {
-#  if defined(__linux) || defined(__APPLE__) || defined(__FreeBSD__)
+#  if defined(__linux__) || defined(__APPLE__) || defined(__FreeBSD__)
         struct ifaddrs* ifap;
         if(::getifaddrs(&ifap) != SOCKET_ERROR)
         {
@@ -660,7 +660,7 @@ getInterfaceIndex(const string& intf)
                     struct sockaddr_in6* ipv6Addr = reinterpret_cast<struct sockaddr_in6*>(curr->ifa_addr);
                     if(memcmp(&addr, &ipv6Addr->sin6_addr, sizeof(in6_addr)) == 0)
                     {
-                        index = if_nametoindex(curr->ifa_name);
+                        index = static_cast<int>(if_nametoindex(curr->ifa_name));
                         break;
                     }
                 }
@@ -725,7 +725,7 @@ getInterfaceIndex(const string& intf)
                     struct sockaddr_in6* ipv6Addr = reinterpret_cast<struct sockaddr_in6*>(&ifr[i].ifr_addr);
                     if(memcmp(&addr, &ipv6Addr->sin6_addr, sizeof(in6_addr)) == 0)
                     {
-                        index = if_nametoindex(ifr[i].ifr_name);
+                        index = static_cast<int>(if_nametoindex(ifr[i].ifr_name));
                         break;
                     }
                 }
@@ -736,7 +736,7 @@ getInterfaceIndex(const string& intf)
     }
     else // Look for an interface with the given name.
     {
-        index = if_nametoindex(name.c_str());
+        index = static_cast<int>(if_nametoindex(name.c_str()));
     }
     if(index <= 0)
     {
@@ -1821,7 +1821,8 @@ IceInternal::inetAddrToString(const Address& ss)
 
     char namebuf[1024];
     namebuf[0] = '\0';
-    getnameinfo(&ss.sa, size, namebuf, static_cast<socklen_t>(sizeof(namebuf)), 0, 0, NI_NUMERICHOST);
+    getnameinfo(&ss.sa, static_cast<socklen_t>(size), namebuf, static_cast<socklen_t>(sizeof(namebuf)), 0, 0,
+                NI_NUMERICHOST);
     return string(namebuf);
 #else
     if(ss.host == nullptr)
@@ -2161,7 +2162,7 @@ IceInternal::setMcastGroup(SOCKET fd, const Address& group, const string& intf)
                 indexes.insert(index);
                 struct ipv6_mreq mreq;
                 mreq.ipv6mr_multiaddr = group.saIn6.sin6_addr;
-                mreq.ipv6mr_interface = index;
+                mreq.ipv6mr_interface = static_cast<unsigned int>(index);
                 rc = setsockopt(fd, IPPROTO_IPV6, IPV6_JOIN_GROUP, reinterpret_cast<char*>(&mreq), int(sizeof(mreq)));
             }
         }
@@ -2404,7 +2405,7 @@ IceInternal::doBind(SOCKET fd, const Address& addr, const string&)
     int size = getAddressStorageSize(addr);
     assert(size != 0);
 
-    if(::bind(fd, &addr.sa, size) == SOCKET_ERROR)
+    if(::bind(fd, &addr.sa, static_cast<socklen_t>(size)) == SOCKET_ERROR)
     {
         closeSocketNoThrow(fd);
         throw SocketException(__FILE__, __LINE__, getSocketErrno());
@@ -2626,7 +2627,7 @@ repeatConnect:
     int size = getAddressStorageSize(addr);
     assert(size != 0);
 
-    if(::connect(fd, &addr.sa, size) == SOCKET_ERROR)
+    if(::connect(fd, &addr.sa, static_cast<socklen_t>(size)) == SOCKET_ERROR)
     {
         if(interrupted())
         {
@@ -2653,7 +2654,7 @@ repeatConnect:
         }
     }
 
-#if defined(__linux)
+#if defined(__linux__)
     //
     // Prevent self connect (self connect happens on Linux when a client tries to connect to
     // a server which was just deactivated if the client socket re-uses the same ephemeral
@@ -2722,7 +2723,7 @@ IceInternal::doFinishConnect(SOCKET fd)
         }
     }
 
-#if defined(__linux)
+#if defined(__linux__)
     //
     // Prevent self connect (self connect happens on Linux when a client tries to connect to
     // a server which was just deactivated if the client socket re-uses the same ephemeral
