@@ -965,7 +965,7 @@ allTests(Test::TestHelper* helper, const CommunicatorObserverIPtr& obsv)
     cout << "testing invocation metrics... " << flush;
 
     props["IceMX.Metrics.View.Map.Invocation.GroupBy"] = "operation";
-    props["IceMX.Metrics.View.Map.Invocation.Map.Remote.GroupBy"] = "localPort";
+    props["IceMX.Metrics.View.Map.Invocation.Map.Remote.GroupBy"] = "id";
     props["IceMX.Metrics.View.Map.Invocation.Map.Collocated.GroupBy"] = "parent";
     updateProps(clientProps, serverProps, update.get(), props, "Invocation");
     test(serverMetrics->getMetricsView("View", timestamp)["Invocation"].empty());
@@ -1323,13 +1323,20 @@ allTests(Test::TestHelper* helper, const CommunicatorObserverIPtr& obsv)
     if(!collocated)
     {
         im1 = ICE_DYNAMIC_CAST(IceMX::InvocationMetrics, map["fail"]);
-        test(im1->current <= 1 && im1->total == 3 && im1->failures == 3 && im1->retry == 3 && im1->remotes.size() == 6);
-        test(im1->remotes[0]->current == 0 && im1->remotes[0]->total == 1 && im1->remotes[0]->failures == 1);
-        test(im1->remotes[1]->current == 0 && im1->remotes[1]->total == 1 && im1->remotes[1]->failures == 1);
-        test(im1->remotes[2]->current == 0 && im1->remotes[2]->total == 1 && im1->remotes[2]->failures == 1);
-        test(im1->remotes[3]->current == 0 && im1->remotes[3]->total == 1 && im1->remotes[3]->failures == 1);
-        test(im1->remotes[4]->current == 0 && im1->remotes[4]->total == 1 && im1->remotes[4]->failures == 1);
-        test(im1->remotes[5]->current == 0 && im1->remotes[5]->total == 1 && im1->remotes[5]->failures == 1);
+        test(im1->current <= 1 && im1->total == 3 && im1->failures == 3 && im1->retry == 3 && im1->remotes.size() == 1);
+        rim1 = ICE_DYNAMIC_CAST(IceMX::ChildInvocationMetrics, im1->remotes[0]);
+        if(rim1->current != 0 || rim1->total != 6 || rim1->failures != 6)
+        {
+            cerr << "rim1->current = " << rim1->current << endl;
+            cerr << "rim1->total = " << rim1->total << endl;
+            cerr << "rim1->failures = " << rim1->failures << endl;
+            IceMX::MetricsFailures f = clientMetrics->getMetricsFailures("View", "Invocation", im1->id);
+            for(IceMX::StringIntDict::const_iterator p = f.failures.begin(); p != f.failures.end(); ++p)
+            {
+                cerr << p->first << " = " << p->second << endl;
+            }
+        }
+        test(rim1->current == 0 && rim1->total == 6 && rim1->failures == 6);
         checkFailure(clientMetrics, "Invocation", im1->id, "::Ice::ConnectionLostException", 3);
     }
 
