@@ -57,6 +57,12 @@ RetryI::opSystemException(const Ice::Current&)
     throw SystemFailure(__FILE__, __LINE__);
 }
 
+void
+RetryI::sleep(int delay, const Ice::Current&)
+{
+    IceUtil::ThreadControl::sleep(IceUtil::Time::milliSeconds(delay));
+}
+
 void
 RetryI::shutdown(const Ice::Current& current)
 {
