@@ -80,7 +80,11 @@ namespace IceInternal
             //_observer = null;
             Debug.Assert(_observer == null);
 
-            _os = null;
+            if(_os != null)
+            {
+                _os.reset(); // Reset the output stream to prepare it for re-use.
+            }
+
             _is = null;
 
             //_responseHandler = null;
@@ -264,17 +268,27 @@ namespace IceInternal
         {
             if(task == null)
             {
-                _os = startWriteParams();
-                write(_os, default(R));
-                endWriteParams(_os);
-                return null; // Response is cached in the Incoming to not have to create unecessary Task
+                //
+                // Write default constructed response if no task is provided
+                //
+                var os = startWriteParams();
+                write(os, default(R));
+                endWriteParams(os);
+                return setResult(os);
             }
             else
             {
+                var cached = getAndClearCachedOutputStream(); // If an output stream is cached, re-use it
+
+                //
+                // NOTE: it's important that the continuation doesn't mutate the Incoming state to
+                // guarantee thread-safety. Multiple continuations can execute concurrently if the
+                // user installed a dispatch interceptor and the dispatch is retried.
+                //
                 return task.ContinueWith((Task<R> t) =>
                 {
                     var result = t.GetAwaiter().GetResult();
-                    var os = startWriteParams();
+                    var os = startWriteParams(cached);
                     write(os, result);
                     endWriteParams(os);
                     return Task.FromResult(os);
@@ -286,15 +300,24 @@ namespace IceInternal
         {
             if(task == null)
             {
-                _os = writeEmptyParams();
-                return null;
+                //
+                // Write response if no task is provided
+                //
+                return setResult(writeEmptyParams());
             }
             else
             {
+                var cached = getAndClearCachedOutputStream(); // If an output stream is cached, re-use it
+
+                //
+                // NOTE: it's important that the continuation doesn't mutate the Incoming state to
+                // guarantee thread-safety. Multiple continuations can execute concurrently if the
+                // user installed a dispatch interceptor and the dispatch is retried.
+                //
                 return task.ContinueWith((Task t) =>
                 {
                     t.GetAwaiter().GetResult();
-                    return Task.FromResult(writeEmptyParams());
+                    return Task.FromResult(writeEmptyParams(cached));
                 }, TaskContinuationOptions.ExecuteSynchronously).Unwrap();
             }
         }
@@ -303,11 +326,15 @@ namespace IceInternal
         {
             if(task == null)
             {
-                _os = default(T).getOutputStream(_current);
-                return null; // Response is cached in the Incoming to not have to create unecessary Task
+                return setResult(default(T).getOutputStream(_current));
             }
             else
             {
+                //
+                // NOTE: it's important that the continuation doesn't mutate the Incoming state to
+                // guarantee thread-safety. Multiple continuations can execute concurrently if the
+                // user installed a dispatch interceptor and the dispatch is retried.
+                //
                 return task.ContinueWith((Task<T> t) =>
                 {
                     return Task.FromResult(t.GetAwaiter().GetResult().getOutputStream(_current));
@@ -382,7 +409,10 @@ namespace IceInternal
                 // Let's rewind _is, reset _os
                 //
                 _is.pos(_inParamPos);
-                _os = null;
+                if(_response && _os != null)
+                {
+                    _os.reset();
+                }
             }
         }
 
@@ -425,6 +455,20 @@ namespace IceInternal
             _format = format;
         }
 
+        public Ice.OutputStream getAndClearCachedOutputStream()
+        {
+            if(_response)
+            {
+                var cached = _os;
+                _os = null;
+                return cached;
+            }
+            else
+            {
+                return null; // Don't consume unnecessarily the output stream if we are dispatching a oneway request
+            }
+        }
+
         static public Ice.OutputStream createResponseOutputStream(Ice.Current current)
         {
             var os = new Ice.OutputStream(current.adapter.getCommunicator(), Ice.Util.currentProtocolEncoding);
@@ -434,14 +478,18 @@ namespace IceInternal
             return os;
         }
 
-        public Ice.OutputStream startWriteParams()
+        private Ice.OutputStream startWriteParams(Ice.OutputStream os)
         {
             if(!_response)
             {
                 throw new Ice.MarshalException("can't marshal out parameters for oneway dispatch");
             }
 
-            var os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
+            if(os == null) // Create the output stream if none is provided
+            {
+                os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
+            }
+            Debug.Assert(os.pos() == 0);
             os.writeBlob(Protocol.replyHdr);
             os.writeInt(_current.requestId);
             os.writeByte(ReplyStatus.replyOK);
@@ -449,6 +497,11 @@ namespace IceInternal
             return os;
         }
 
+        public Ice.OutputStream startWriteParams()
+        {
+            return startWriteParams(getAndClearCachedOutputStream());
+        }
+
         public void endWriteParams(Ice.OutputStream os)
         {
             if(_response)
@@ -457,11 +510,15 @@ namespace IceInternal
             }
         }
 
-        public Ice.OutputStream writeEmptyParams()
+        private Ice.OutputStream writeEmptyParams(Ice.OutputStream os)
         {
             if(_response)
             {
-                var os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
+                if(os == null) // Create the output stream if none is provided
+                {
+                    os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
+                }
+                Debug.Assert(os.pos() == 0);
                 os.writeBlob(Protocol.replyHdr);
                 os.writeInt(_current.requestId);
                 os.writeByte(ReplyStatus.replyOK);
@@ -474,7 +531,12 @@ namespace IceInternal
             }
         }
 
-        public Ice.OutputStream writeParamEncaps(byte[] v, bool ok)
+        public Ice.OutputStream writeEmptyParams()
+        {
+            return writeEmptyParams(getAndClearCachedOutputStream());
+        }
+
+        public Ice.OutputStream writeParamEncaps(Ice.OutputStream os, byte[] v, bool ok)
         {
             if(!ok && _observer != null)
             {
@@ -483,7 +545,11 @@ namespace IceInternal
 
             if(_response)
             {
-                var os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
+                if(os == null) // Create the output stream if none is provided
+                {
+                    os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
+                }
+                Debug.Assert(os.pos() == 0);
                 os.writeBlob(Protocol.replyHdr);
                 os.writeInt(_current.requestId);
                 os.writeByte(ok ? ReplyStatus.replyOK : ReplyStatus.replyUserException);
@@ -552,6 +618,21 @@ namespace IceInternal
                 }
             }
 
+            if(_response)
+            {
+                //
+                // If there's already a response output stream, reset it to re-use it
+                //
+                if(_os != null)
+                {
+                    _os.reset();
+                }
+                else
+                {
+                    _os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
+                }
+            }
+
             try
             {
                 throw exc;
@@ -585,7 +666,6 @@ namespace IceInternal
 
                 if(_response)
                 {
-                    _os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
                     _os.writeBlob(Protocol.replyHdr);
                     _os.writeInt(_current.requestId);
                     if(ex is Ice.ObjectNotExistException)
@@ -646,7 +726,6 @@ namespace IceInternal
 
                 if(_response)
                 {
-                    _os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
                     _os.writeBlob(Protocol.replyHdr);
                     _os.writeInt(_current.requestId);
                     _os.writeByte(ReplyStatus.replyUnknownLocalException);
@@ -676,7 +755,6 @@ namespace IceInternal
 
                 if(_response)
                 {
-                    _os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
                     _os.writeBlob(Protocol.replyHdr);
                     _os.writeInt(_current.requestId);
                     _os.writeByte(ReplyStatus.replyUnknownUserException);
@@ -707,7 +785,6 @@ namespace IceInternal
 
                 if(_response)
                 {
-                    _os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
                     _os.writeBlob(Protocol.replyHdr);
                     _os.writeInt(_current.requestId);
                     _os.writeByte(ReplyStatus.replyUnknownException);
@@ -732,7 +809,6 @@ namespace IceInternal
 
                 if(_response)
                 {
-                    _os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
                     _os.writeBlob(Protocol.replyHdr);
                     _os.writeInt(_current.requestId);
                     _os.writeByte(ReplyStatus.replyUserException);
@@ -764,7 +840,6 @@ namespace IceInternal
 
                 if(_response)
                 {
-                    _os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
                     _os.writeBlob(Protocol.replyHdr);
                     _os.writeInt(_current.requestId);
                     _os.writeByte(ReplyStatus.replyUnknownLocalException);
@@ -794,7 +869,6 @@ namespace IceInternal
 
                 if(_response)
                 {
-                    _os = new Ice.OutputStream(_instance, Ice.Util.currentProtocolEncoding);
                     _os.writeBlob(Protocol.replyHdr);
                     _os.writeInt(_current.requestId);
                     _os.writeByte(ReplyStatus.replyUnknownException);
