@@ -911,7 +911,7 @@ public class AllTests
         out.flush();
 
         props.put("IceMX.Metrics.View.Map.Invocation.GroupBy", "operation");
-        props.put("IceMX.Metrics.View.Map.Invocation.Map.Remote.GroupBy", "localPort");
+        props.put("IceMX.Metrics.View.Map.Invocation.Map.Remote.GroupBy", "id");
         props.put("IceMX.Metrics.View.Map.Invocation.Map.Collocated.GroupBy", "id");
         updateProps(clientProps, serverProps, props, "Invocation");
         test(serverMetrics.getMetricsView("View").returnValue.get("Invocation").length == 0);
@@ -1094,13 +1094,11 @@ public class AllTests
         if(!collocated)
         {
             im1 = (InvocationMetrics)map.get("fail");
-            test(im1.current <= 1 && im1.total == 3 && im1.failures == 3 && im1.retry == 3 && im1.remotes.length == 6);
-            test(im1.remotes[0].current == 0 && im1.remotes[0].total == 1 && im1.remotes[0].failures == 1);
-            test(im1.remotes[1].current == 0 && im1.remotes[1].total == 1 && im1.remotes[1].failures == 1);
-            test(im1.remotes[2].current == 0 && im1.remotes[2].total == 1 && im1.remotes[2].failures == 1);
-            test(im1.remotes[3].current == 0 && im1.remotes[3].total == 1 && im1.remotes[3].failures == 1);
-            test(im1.remotes[4].current == 0 && im1.remotes[4].total == 1 && im1.remotes[4].failures == 1);
-            test(im1.remotes[5].current == 0 && im1.remotes[5].total == 1 && im1.remotes[5].failures == 1);
+            test(im1.current <= 1 && im1.total == 3 && im1.failures == 3 && im1.retry == 3 && im1.remotes.length == 1);
+            rim1 = (ChildInvocationMetrics)im1.remotes[0];
+            test(rim1.current == 0);
+            test(rim1.total == 6);
+            test(rim1.failures == 6);
             checkFailure(clientMetrics, "Invocation", im1.id, "::Ice::ConnectionLostException", 3, out);
         }
 
