@@ -101,6 +101,7 @@ classdef ObjectPrx < IceInternal.WrapperObject
     %   ice_getTimeout - Obtains the timeout override of this proxy.
     %   ice_fixed - Obtains a proxy that is identical to this proxy, except it's
     %     a fixed proxy bound to the given connection.
+    %   ice_isFixed - Returns whether this proxy is a fixed proxy.
     %   ice_getConnection - Returns the Connection for this proxy.
     %   ice_getConnectionAsync - Returns the Connection for this proxy.
     %   ice_getCachedConnection - Returns the cached Connection for this
@@ -886,6 +887,14 @@ classdef ObjectPrx < IceInternal.WrapperObject
             r = obj.factory_('ice_fixed', true, connection.iceGetImpl());
         end
 
+        function r = ice_isFixed(obj)
+            % ice_isFixed - Determines whether this proxy is a fixed proxy.
+            %
+            % Returns (logical) - True if this proxy is a fixed proxy, false otherwise.
+
+            r = obj.iceCallWithResult('ice_isFixed');
+        end
+
         function r = ice_getConnection(obj)
             % ice_getConnection - Returns the Connection for this proxy. If the
             %   proxy does not yet have an established connection, it first
@@ -952,9 +961,8 @@ classdef ObjectPrx < IceInternal.WrapperObject
         end
 
         function r = ice_flushBatchRequestsAsync(obj)
-            % ice_flushBatchRequestsAsync - Flushes any pending batched
-            %   requests for this communicator. The call blocks until the
-            %   flush is complete.
+            % ice_flushBatchRequestsAsync - Flushes asynchronously any pending batched
+            %   requests for this communicator.
             %
             % Returns (Ice.Future) - A future that will be completed when the
             %   invocation completes.
@@ -1228,7 +1236,11 @@ classdef ObjectPrx < IceInternal.WrapperObject
                     r = p;
                 end
             catch ex
-                ex.throwAsCaller();
+                if isa(ex, 'Ice.FacetNotExistException')
+                    r = [];
+                else
+                    ex.throwAsCaller();
+                end
             end
         end
 
