@@ -6,6 +6,7 @@ classdef AllTests
     methods(Static)
         function r = allTests(helper)
             import Test.*;
+            import M.*;
 
             communicator = helper.communicator();
             ref = ['test:', helper.getTestEndpoint()];
@@ -13,9 +14,11 @@ classdef AllTests
             cl = MyClassPrx.checkedCast(base);
             derived = MyDerivedClassPrx.checkedCast(cl);
 
+            bprx = BPrx.checkedCast(communicator.stringToProxy(['b:', helper.getTestEndpoint()]));
+
             fprintf('testing twoway operations... ');
-            Twoways.twoways(helper, cl);
-            Twoways.twoways(helper, derived);
+            Twoways.twoways(helper, cl, bprx);
+            Twoways.twoways(helper, derived, bprx);
             derived.opDerived();
             fprintf('ok\n');
 
