@@ -5,6 +5,7 @@
 #import <objc/Ice.h>
 #import <TestCommon.h>
 #import <ObjectsTest.h>
+#import <ObjectsForward.h>
 
 #if defined(__clang__)
 // For 'Ice::Communicator::findObjectFactory()' deprecation
@@ -688,5 +689,22 @@ objectsAllTests(id<ICECommunicator> communicator, BOOL __unused collocated)
         tprintf("ok\n");
     }
 
+    {
+        tprintf("testing forward declarations... ");
+        TestObjectsF1* f12;
+        TestObjectsF1* f11 = [initial opF1:[[TestObjectsF1 alloc] init:@"F11"] f12:&f12];
+        test([f11.name isEqualToString:@"F11"]);
+        test([f12.name isEqualToString:@"F12"]);
+
+        TestObjectsF2Prx* f22;
+        ref = @"F21:default -p 12010";
+        TestObjectsF2Prx* f21 = [initial opF2:[TestObjectsF2Prx uncheckedCast:[communicator stringToProxy:ref]]
+                                          f22: &f22];
+        test([[f21 ice_getIdentity].name isEqualToString:@"F21"]);
+        [f21 op];
+        test([[f22 ice_getIdentity].name isEqualToString:@"F22"]);
+        tprintf("ok\n");
+    }
+
     return initial;
 }
