@@ -73,7 +73,7 @@
 @end
 
 void
-twoways(id<ICECommunicator> communicator, id<TestOperationsMyClassPrx> p)
+twoways(id<ICECommunicator> communicator, id<TestOperationsMyClassPrx> p, id<TestOperationsMBPrx> bprx)
 {
     {
         TestOperationsStringS *literals = [p opStringLiterals];
@@ -1460,7 +1460,7 @@ twoways(id<ICECommunicator> communicator, id<TestOperationsMyClassPrx> p)
 
         ICEFloat buf1[] = { -1.1f, 123123.2f, 100.0f };
         ICEFloat buf2[] = { 42.24f, -1.61f };
-        ICEFloat buf3[] = { -3.14, 3.14 };
+        ICEFloat buf3[] = { -3.14f, 3.14f };
 
         TestOperationsMutableFloatS *si1 = [TestOperationsMutableFloatS data];
         TestOperationsMutableFloatS *si2 = [TestOperationsMutableFloatS data];
@@ -1629,17 +1629,17 @@ twoways(id<ICECommunicator> communicator, id<TestOperationsMyClassPrx> p)
     }
 
     {
-        const int lengths[] = { 0, 1, 2, 126, 127, 128, 129, 253, 254, 255, 256, 257, 1000 };
+        const NSUInteger lengths[] = { 0, 1, 2, 126, 127, 128, 129, 253, 254, 255, 256, 257, 1000 };
 
-        int l;
+        NSUInteger l;
         for(l = 0; l != sizeof(lengths) / sizeof(*lengths); ++l)
         {
             TestOperationsMutableIntS *s = [TestOperationsMutableIntS dataWithLength:(lengths[l] * sizeof(ICEInt))];
             ICEInt *ip = (ICEInt *)[s bytes];
-            int i;
+            NSUInteger i;
             for(i = 0; i < lengths[l]; ++i)
             {
-                *ip++ = i;
+                *ip++ = (ICEInt)i;
             }
             TestOperationsIntS *r = [p opIntS:s];
             test([r length] == lengths[l] * sizeof(ICEInt));
@@ -1908,4 +1908,9 @@ twoways(id<ICECommunicator> communicator, id<TestOperationsMyClassPrx> p)
     {
        // Client is talking to non-Objective-C server.
     }
+
+    {
+        [bprx opB];
+        [bprx opIntf];
+    }
 }
