@@ -4,7 +4,7 @@
 #
 
 from TestHelper import TestHelper
-TestHelper.loadSlice("Test.ice ServerPrivate.ice")
+TestHelper.loadSlice("Test.ice Forward.ice ServerPrivate.ice")
 import TestI
 import Ice
 
@@ -32,6 +32,7 @@ class Server(TestHelper):
             adapter = communicator.createObjectAdapter("TestAdapter")
             initial = TestI.InitialI(adapter)
             adapter.add(initial, Ice.stringToIdentity("initial"))
+            adapter.add(TestI.F2I(), Ice.stringToIdentity("F21"))
             uoet = TestI.UnexpectedObjectExceptionTestI()
             adapter.add(uoet, Ice.stringToIdentity("uoet"))
             adapter.activate()
