@@ -11,10 +11,12 @@ def allTests(helper, communicator)
     cl = Test::MyClassPrx::checkedCast(base)
     derived = Test::MyDerivedClassPrx::checkedCast(cl)
 
+    bprx = M::BPrx::checkedCast(communicator.stringToProxy("b:#{helper.getTestEndpoint()}"))
+
     print "testing twoway operations... "
     STDOUT.flush
-    twoways(helper, communicator, cl)
-    twoways(helper, communicator, derived)
+    twoways(helper, communicator, cl, bprx)
+    twoways(helper, communicator, derived, bprx)
     derived.opDerived()
     puts "ok"
 
