@@ -171,7 +171,11 @@ def allTests(helper, communicator)
     test(mo5.h == mo1.h)
     test(mo5.i == mo1.i)
     test(mo5.j == mo1.j)
-    test(mo5.k == nil)
+    #
+    # With Swift mapping you cannot distinguish null from unset
+    # so we test for both here to support cross testing.
+    #
+    test(mo5.k == nil || Ice::Unset)
     test(mo5.bs.unpack("C*") == [0x05])
     test(mo5.ss == mo1.ss)
     test(mo5.iid[4] == 3)
