@@ -4,6 +4,7 @@
 
 import sys, os
 from Util import *
+from Component import component
 
 class IceBox(ProcessFromBinDir, Server):
 
@@ -45,6 +46,9 @@ class IceBox(ProcessFromBinDir, Server):
                platform.getLinuxId() in ["centos", "rhel", "fedora"] and \
                current.config.buildPlatform == "x86":
                 name += "32" # Multilib platform
+            if isinstance(platform, AIX) and \
+               current.config.buildPlatform == "ppc":
+                name += "_32"
             if current.config.cpp11:
                 name += "++11"
             return name
@@ -75,5 +79,8 @@ class IceBoxAdmin(ProcessFromBinDir, ProcessIsReleaseOnly, Client):
             return "IceBox.Admin"
         elif isinstance(mapping, JavaMapping):
             return "com.zeroc.IceBox.Admin"
+        elif isinstance(platform, AIX) and \
+             current.config.buildPlatform == "ppc" and not component.useBinDist(mapping, current):
+            return "iceboxadmin_32"
         else:
             return "iceboxadmin"
